package com.zanxiang.manage.controller;

import com.zanxiang.common.domain.ResultVo;
import com.zanxiang.common.enums.HttpStatusEnum;
import com.zanxiang.common.utils.bean.BeanUtils;
import com.zanxiang.manage.domain.bo.PayApplicationBO;
import com.zanxiang.manage.domain.bo.PayMerchantBO;
import com.zanxiang.manage.domain.dto.PayApplicationDTO;
import com.zanxiang.manage.domain.dto.PayMerchantDTO;
import com.zanxiang.manage.domain.params.PayApplicationParam;
import com.zanxiang.manage.domain.params.PayMerchantParam;
import com.zanxiang.manage.domain.vo.PayApplicationVO;
import com.zanxiang.manage.domain.vo.PayMerchantVO;
import com.zanxiang.manage.service.PayApplicationService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 游戏应用
 *
 * @author xufeng
 * @date 2022-06-20 15:16
 */
@Api(tags = "游戏应用管理")
@RestController
@RequestMapping("/pay-application")
public class PayApplicationController {

    @Autowired
    private PayApplicationService payApplicationService;

    @ApiOperation(value = "新增/编辑/删除")
    @PostMapping(value = "/save")
    public ResultVo<Boolean> save(@Validated @RequestBody PayApplicationParam param) {
        Boolean result = payApplicationService.saveOrUpdate(BeanUtils.copy(param, PayApplicationBO.class));
        if (result) {
            return new ResultVo<>(HttpStatusEnum.SUCCESS, true);
        }
        return new ResultVo<>(HttpStatusEnum.FAIL, false);
    }

    @ApiOperation(value = "列表")
    @PostMapping(value = "/list")
    public ResultVo<List<PayApplicationVO>> list(@Validated @RequestBody PayApplicationParam param) {
        List<PayApplicationDTO> result = payApplicationService.list(BeanUtils.copy(param, PayApplicationBO.class));
        if (!result.isEmpty()) {
            List<PayApplicationVO> list = BeanUtils.copyList(result, PayApplicationVO.class);
            return new ResultVo<>(HttpStatusEnum.SUCCESS, list);
        }
        return new ResultVo<>(HttpStatusEnum.FAIL);
    }
}
