package com.zanxiang.manage.controller;

import com.zanxiang.common.domain.ResultVo;
import com.zanxiang.common.enums.HttpStatusEnum;
import com.zanxiang.common.utils.bean.BeanUtils;
import com.zanxiang.manage.domain.bo.PayMerchantBO;
import com.zanxiang.manage.domain.dto.PayMerchantDTO;
import com.zanxiang.manage.domain.params.PayMerchantParam;
import com.zanxiang.manage.domain.vo.PayMerchantVO;
import com.zanxiang.manage.service.PayMerchantService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 游戏支付商户配置表 前端控制器
 *
 * @author xufeng
 * @date 2022-06-16 19:04
 */
@Api(tags = "商户号管理")
@RestController
@RequestMapping("/pay-merchant")
public class PayMerchantController {

    @Autowired
    private PayMerchantService payMerchantService;

    @ApiOperation(value = "商户号-新增/编辑/删除(payWayId/merchantNo/merchantName 必传)")
    @PostMapping(value = "/save")
    public ResultVo<String> create(@Validated @RequestBody PayMerchantParam param) {
        Boolean result = payMerchantService.saveOrUpdate(BeanUtils.copy(param, PayMerchantBO.class));
        if (result) {
            return new ResultVo(HttpStatusEnum.SUCCESS, result);
        }
        return new ResultVo(HttpStatusEnum.FAIL, result);
    }

    @ApiOperation(value = "商户号-列表")
    @PostMapping(value = "/list")
    public ResultVo<PayMerchantVO> list(@Validated @RequestBody PayMerchantParam param) {
        List<PayMerchantDTO> result = payMerchantService.list(BeanUtils.copy(param, PayMerchantBO.class));
        if (!result.isEmpty()) {
            return new ResultVo(HttpStatusEnum.SUCCESS, result);
        }
        return new ResultVo(HttpStatusEnum.FAIL);
    }

    @ApiOperation(value = "盒子-列表")
    @PostMapping(value = "/box-list")
    public ResultVo<PayMerchantVO> boxList(@Validated @RequestBody PayMerchantParam param) {
        List<PayMerchantDTO> result = payMerchantService.list(BeanUtils.copy(param, PayMerchantBO.class));
        if (!result.isEmpty()) {
            return new ResultVo(HttpStatusEnum.SUCCESS, result);
        }
        return new ResultVo(HttpStatusEnum.FAIL);
    }

}
